==> haskell-hls-stylish-haskell-plugin-2.1.0.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-stylish-haskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-stylish-haskell-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-stylish-haskell-plugin-2.1.0.0-9ZBjgMO7iNJJiCdnqv7Cbm
key:                  hls-stylish-haskell-plugin-2.1.0.0-9ZBjgMO7iNJJiCdnqv7Cbm
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  e1e85a941768c70bae25915bc04c4a76
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-2.1.0.0-9ZBjgMO7iNJJiCdnqv7Cbm
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2 ghc-9.4.8
    ghc-boot-th-9.4.8 ghcide-2.1.0.0-1KOcaMBafULLEncWomo7Qk
    hls-plugin-api-2.1.0.0-KSS8kWBQYXNJC6hz6fAtRu
    lsp-types-2.0.1.0-CpSI1ypjR9r72V9wDhxm76 mtl-2.2.2
    stylish-haskell-0.14.4.0-18AYbuxMRGVFbGN03ArzCM text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-stylish-haskell-plugin-2.1.0.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-stylish-haskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-stylish-haskell-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-stylish-haskell-plugin-2.1.0.0-Ksp7M3Elnu27LBQ4CTiE4k
key:                  hls-stylish-haskell-plugin-2.1.0.0-Ksp7M3Elnu27LBQ4CTiE4k
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  72182da94ef046f94b03f5b005c2589b
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-stylish-haskell-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-2.1.0.0-Ksp7M3Elnu27LBQ4CTiE4k
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2 ghc-9.4.8
    ghc-boot-th-9.4.8 ghcide-2.1.0.0-8JBpStbo1B4AALTMcYIo2m
    hls-plugin-api-2.1.0.0-H3CXeXeKkzR8GXL5hkOqhn
    lsp-types-2.0.1.0-ERiHsbrIFJX8GWb1FzfnMP mtl-2.2.2
    stylish-haskell-0.14.4.0-18AYbuxMRGVFbGN03ArzCM text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
